@@ -10,11 +10,18 @@ import time
 import yaml
 
 
-def get_grow_dir():
+def is_packaged_app():
   try:
-    return os.path.join(sys._MEIPASS)
+    sys._MEIPASS
+    return True
   except AttributeError:
-    return os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
+    return False
+
+
+def get_grow_dir():
+  if is_packaged_app():
+    return os.path.join(sys._MEIPASS)
+  return os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
 
 
 def interactive_confirm(message, default=False):
@@ -38,6 +45,8 @@ def walk(node, callback):
 
 def colorize(text):
   return text.format(**{
+    'blue': '\033[0;34m',
+    '/blue': '\033[0;m',
     'red': '\033[0;31m',
     '/red': '\033[0;m',
     'green': '\033[0;32m',
