@@ -4,7 +4,7 @@ from grow.deployments.google_cloud_storage import *
 from grow.deployments.google_cloud_storage_from_app_engine import *
 from grow.deployments.podserver import *
 from grow.deployments.zip_file import *
-
+from grow.deployments.scp import *
 
 
 class Deployment(object):
@@ -17,4 +17,6 @@ class Deployment(object):
       return AmazonS3Deployment(*args, **kwargs)
     elif kind == 'local':
       return FileSystemDeployment(*args, **kwargs)
+    elif kind == 'scp':
+      return ScpDeployment(*args, **kwargs)
     raise ValueError('No configuration exists for "{}".'.format(kind))
