@@ -1,4 +1,5 @@
 from grow.deployments import base
+from grow.pods.storage import storage as storage_lib
 import os
 
 
@@ -7,8 +8,8 @@ class FileSystemDeployment(base.BaseDeployment):
   def get_destination_address(self):
     return self.out_dir
 
-  def set_params(self, storage, out_dir):
-    self.out_dir = out_dir
+  def set_params(self, out_dir, storage=storage_lib.FileStorage):
+    self.out_dir = os.path.expanduser(out_dir)
     self.storage = storage
 
   def read_file(self, path):
