@@ -1,10 +1,11 @@
 import logging
 logging.basicConfig(level=logging.INFO, format='%(message)s')
 
+from grow.common import utils
+from grow.pods.preprocessors import translation as translation_preprocessor
 from grow.pods.preprocessors.file_watchers import file_watchers
 from grow.server import handlers
 from grow.server import main as main_lib
-from grow.common import utils
 from wsgiref import simple_server
 import atexit
 import multiprocessing
@@ -12,6 +13,7 @@ import os
 import sys
 import threading
 import yaml
+import webbrowser
 
 _servers = {}
 _config_path = '{}/.grow/servers.yaml'.format(os.environ['HOME'])
@@ -25,53 +27,50 @@ def _loop_watching_for_changes(pod, file_watchers_to_preprocessors, quit_event):
     quit_event.wait(timeout=1.5)
 
 
-def _start(pod, host=None, port=None, use_simple_log_format=True):
+def _start(pod, host=None, port=None, open_browser=False):
   root = pod.root
   preprocessors = pod.list_preprocessors()
 
-  # Map directory names to preprocessors.
-  dirs_to_preprocessors = {}
-  for preprocessor in preprocessors:
-    for watched_dir in preprocessor.list_watched_dirs():
-      if watched_dir not in dirs_to_preprocessors:
-        dirs_to_preprocessors[watched_dir] = []
-      dirs_to_preprocessors[watched_dir].append(preprocessor)
-
-  # Run all preprocessors for the pod.
-  [preprocessor.run() for preprocessor in preprocessors]
-
-  # Create file watchers for each preprocessor.
-  file_watchers_to_preprocessors = {}
-  for dirname, preprocessors in dirs_to_preprocessors.iteritems():
-    dirname = os.path.join(pod.root, dirname.lstrip('/'))
-    change_watcher = file_watchers.get_file_watcher([dirname])
-    change_watcher.start()
-    file_watchers_to_preprocessors[change_watcher] = preprocessors
-
-  # Start a thread where preprocessors can run if there are changes.
-  quit_event = threading.Event()
-  change_watcher_thread = threading.Thread(
-      target=_loop_watching_for_changes,
-      args=(pod, file_watchers_to_preprocessors, quit_event))
-  change_watcher_thread.start()
-
-  # Compile translations.
-  # TODO(jeremydw): Move to TranslationPreprocessor.
-  translations_obj = pod.get_translations()
-  translations_obj.recompile_mo_files()
-
-  root = os.path.abspath(os.path.normpath(root))
-  logger_format = ('[%(time)s] "%(REQUEST_METHOD)s %(REQUEST_URI)s" %(status)s'
-                   if use_simple_log_format else None)
-
-  # Start the actual server.
-  handlers.set_pod_root(root)
-  app = main_lib.application
-
-  port = 8080 if port is None else port
-  host = 'localhost' if host is None else host
+  # Add the translation preprocessor as a builtin.
+  preprocessors.insert(0, translation_preprocessor.TranslationPreprocessor(pod=pod))
 
   try:
+    # TODO(jeremydw): Custom server logs.
+    # logger_format = ('[%(time)s] "%(REQUEST_METHOD)s %(REQUEST_URI)s" %(status)s'
+    #                 if use_simple_log_format else None)
+
+    # Map directory names to preprocessors.
+    dirs_to_preprocessors = {}
+    for preprocessor in preprocessors:
+      for watched_dir in preprocessor.list_watched_dirs():
+        if watched_dir not in dirs_to_preprocessors:
+          dirs_to_preprocessors[watched_dir] = []
+        dirs_to_preprocessors[watched_dir].append(preprocessor)
+
+    # Run all preprocessors for the pod.
+    [preprocessor.first_run() for preprocessor in preprocessors]
+
+    # Create file watchers for each preprocessor.
+    file_watchers_to_preprocessors = {}
+    for dirname, preprocessors in dirs_to_preprocessors.iteritems():
+      dirname = os.path.join(pod.root, dirname.lstrip('/'))
+      change_watcher = file_watchers.get_file_watcher([dirname])
+      change_watcher.start()
+      file_watchers_to_preprocessors[change_watcher] = preprocessors
+
+    # Start a thread where preprocessors can run if there are changes.
+    quit_event = threading.Event()
+    change_watcher_thread = threading.Thread(
+        target=_loop_watching_for_changes,
+        args=(pod, file_watchers_to_preprocessors, quit_event))
+    change_watcher_thread.start()
+
+    # Create the development server.
+    root = os.path.abspath(os.path.normpath(root))
+    handlers.set_pod_root(root)
+    app = main_lib.application
+    port = 8080 if port is None else port
+    host = 'localhost' if host is None else host
     httpd = simple_server.make_server(host, int(port), app)
   except:
     logging.exception('Failed to start server.')
@@ -80,14 +79,28 @@ def _start(pod, host=None, port=None, use_simple_log_format=True):
     sys.exit()
 
   try:
+    root_path = pod.get_root_path()
+    url = 'http://{}:{}{}'.format(host, port, root_path)
     logging.info('---')
-    logging.info(utils.colorize('{yellow}The Grow SDK is experimental.{/yellow} Expect backwards incompatibility until v0.1.0.'))
+    logging.info(utils.colorize('{blue}The Grow SDK is experimental.{/blue} Expect backwards incompatibility until v0.1.0.'))
     logging.info('Thank you for testing and contributing! Visit http://growsdk.org for resources.')
     logging.info('---')
-    logging.info('Serving pod {} at http://{}:{}'.format(root, host, port))
-    text = '{green}READY!{/green} Press Ctrl+C to shut down.'
+    logging.info('Serving pod {} => {}'.format(root, url))
+    text = '{green}READY!{/green} Press Ctrl+C to shut down. Tip: Use --open to open a browser automatically.'
     logging.info(utils.colorize(text))
+
+    def start_browser(server_ready_event):
+      server_ready_event.wait()
+      if open_browser:
+        webbrowser.open(url)
+
+    server_ready_event = threading.Event()
+    browser_thread = threading.Thread(target=start_browser, args=(server_ready_event,))
+    browser_thread.start()
+    server_ready_event.set()
     httpd.serve_forever()
+    browser_thread.join()
+
   except KeyboardInterrupt:
     logging.info('Shutting down...')
     httpd.server_close()
@@ -98,17 +111,17 @@ def _start(pod, host=None, port=None, use_simple_log_format=True):
   sys.exit()
 
 
-def start(pod, host=None, port=None, use_subprocess=False):
+def start(pod, host=None, port=None, open_browser=False, use_subprocess=False):
   root = pod.root
   if root in _servers:
     logging.error('Server already started for pod: {}'.format(root))
     return
 
   if not use_subprocess:
-    _start(pod, host=host, port=port)
+    _start(pod, host=host, port=port, open_browser=open_browser)
     return
 
-  server_process = multiprocessing.Process(target=_start, args=(root, host, port))
+  server_process = multiprocessing.Process(target=_start, args=(root, host, port, open_browser))
   server_process.start()
   _servers[root] = server_process
   return server_process
